@@ -7,7 +7,7 @@ static const char sccsid[] = "@(#)flag.c	5.00 2000/11/01 xlockmore";
 #endif
 
 /*-
- * Copyright (c) 1996 by Charles Vidal <vidalc@club-internet.fr>
+ * Copyright (c) 1996 by Charles Vidal <cvidal@ivsweb.com>
  *         http://www.chez.com/vidalc
  *
  * Thanks to Bas van Gaalen, Holland, PD, for his Pascal source
@@ -95,7 +95,7 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & invert, (char *) "invert", (char *) "Invert", (char *) DEF_INVERT, t_Bool}
+	{(void *) & invert, (char *) "invert", (char *) "Invert", (char *) DEF_INVERT, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -227,7 +227,7 @@ affiche(ModeInfo * mi)
 			yp = (int) (fp->size * (float) y) + fp->stab[temp];
 			if (MI_NPIXELS(mi) <= 2 || fp->graphics_format < IS_XPM ||
 			    fp->choice == MESSAGE_FLAG) {
-				if (((int) !invert) ^ XGetPixel(fp->image, x, y))
+				if (((int) (!invert)) ^ XGetPixel(fp->image, x, y))
 					XSetForeground(display, fp->backGC, fp->black);
 				else if (MI_NPIXELS(mi) <= 2)
 					XSetForeground(display, fp->backGC, MI_WHITE_PIXEL(mi));
