@@ -19,7 +19,7 @@ static const char sccsid[] = "@(#)sballs.c	5.02 2001/03/10 xlockmore";
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
  *
- * The original code for this mode was written by 
+ * The original code for this mode was written by
  * Mustata Bogdan (LoneRunner) <lonerunner@planetquake.com>
  * and can be found at http://www.cfxweb.net/lonerunner/
  *
@@ -69,7 +69,6 @@ static const char sccsid[] = "@(#)sballs.c	5.02 2001/03/10 xlockmore";
 #define MAX_OBJ		8	/* number of 3D objects */
 
 #include <GL/gl.h>
-#include <GL/glx.h>
 #include <GL/glu.h>
 
 #ifdef HAVE_XPM
@@ -104,9 +103,9 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-    {(caddr_t *) & do_texture, (char *) "texture", (char *) "Texture", (char *) DEF_TEXTURE, t_Bool},
-    {(caddr_t *) & do_trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
-    {(caddr_t *) & object, (char *) "object", (char *) "Object", (char *) DEF_OBJECT, t_Int},
+    {(void *) & do_texture, (char *) "texture", (char *) "Texture", (char *) DEF_TEXTURE, t_Bool},
+    {(void *) & do_trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
+    {(void *) & object, (char *) "object", (char *) "Object", (char *) DEF_OBJECT, t_Int},
 
 };
 
@@ -146,9 +145,12 @@ typedef vec_t vec3_t[3];
 
 /* the mode struct, contains all per screen variables */
 typedef struct {
-    GLint WIDTH, HEIGHT;	/* display dimensions */
+#ifdef WIN32
+    HGLRC glx_context;
+#else
     GLXContext *glx_context;
-
+#endif
+    GLint WIDTH, HEIGHT;	/* display dimensions */
 
     XImage *btexture;		/* back texture image bits */
     XImage *ftexture;		/* face texture image bits */
@@ -313,7 +315,7 @@ static Polyinfo polygons[] =
 
         {
                 "pyramid", "pyramid",   /* long and short names */
-                5,			/* number of vertices */ 
+                5,			/* number of vertices */
 		0.5,
                 {               	/* vertices (x,y,z) */
                         /* all points must be within radius 1 of the origin */
@@ -398,7 +400,7 @@ static void trackmouse(ModeInfo * mi)
     if (fabs(center[0] - (float) cx) > 0.1 * (max[0] - min[0]))
 	sb->rot[0] -= ((center[0] - (float) cx) / (max[0] - min[0]) * 180.0f) / 200.0f;
     if (fabs(center[1] - (float) cy) > 0.1 * (max[1] - min[1]))
-        sb->rot[1] -= ((center[1] - (float) cy) / (max[1] - min[1]) * 180.0f) / 200.0f;;
+        sb->rot[1] -= ((center[1] - (float) cy) / (max[1] - min[1]) * 180.0f) / 200.0f;
     clamp(sb->rot);
 
     /* oops: can't get those buttons */
@@ -626,11 +628,11 @@ static void Draw(ModeInfo * mi)
     sb->rotm[2] += 0;
 
     /* draw the balls */
-    if (do_texture)
 #ifdef HAVE_GLBINDTEXTURE
+    if (do_texture)
        glBindTexture(GL_TEXTURE_2D, sb->faceid);
-#endif /* HAVE_GLBINDTEXTURE */
     else
+#endif /* HAVE_GLBINDTEXTURE */
        glEnable(GL_LIGHTING);
     for (sphere=0;sphere<spheres;sphere++)
     {
@@ -772,8 +774,11 @@ void draw_sballs(ModeInfo * mi)
     MI_IS_DRAWN(mi) = True;
     if (!sb->glx_context)
 	return;
-
+#ifdef WIN32
+    wglMakeCurrent(hdc, sb->glx_context);
+#else
     glXMakeCurrent(display, window, *(sb->glx_context));
+#endif
     Draw(mi);
 #ifndef STANDALONE
     Reshape(mi); /* xlock mode */
@@ -853,7 +858,10 @@ void change_sballs(ModeInfo * mi)
 		       do_texture ? "on" : "off"
 			);
     }
+#ifdef WIN32
+    wglMakeCurrent(hdc, sb->glx_context);
+#else
     glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(sb->glx_context));
-
+#endif
 }
 #endif /* MODE_sballs */
