@@ -37,10 +37,11 @@ static const char sccsid[] = "@(#)sierpinski3D.c	00.01 99/11/04 xlockmore";
 
 #ifdef VMS
 #include "vms_x_fix.h"
-#endif
 #include <X11/Intrinsic.h>
+#endif
 
 #ifdef STANDALONE
+# define MODE_sierpinski3d
 # define PROGCLASS					"Sierpinski3D"
 # define HACK_INIT					init_gasket
 # define HACK_DRAW					draw_gasket
@@ -48,7 +49,7 @@ static const char sccsid[] = "@(#)sierpinski3D.c	00.01 99/11/04 xlockmore";
 # define gasket_opts				xlockmore_opts
 # define DEFAULTS					"*count:		1       \n"			\
 									"*cycles:		9999    \n"			\
-									"*delay:		20000   \n"			\
+									"*delay:		15000   \n"			\
 									"*maxDepth:		5       \n"			\
 									"*speed:		150     \n"			\
 									"*showFPS:      False   \n"			\
@@ -77,11 +78,11 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &max_depth, (char *) "maxdepth", (char *) "MaxDepth",
+  {(void *) &max_depth, (char *) "maxdepth", (char *) "MaxDepth",
      (char *) "5", t_Int},
-  {(caddr_t *) &speed, (char *) "speed", (char *) "Speed",
+  {(void *) &speed, (char *) "speed", (char *) "Speed",
      (char *) "150", t_Int},
-  {(caddr_t *) &intensity, (char *) "intensity", (char *) "Intensity",
+  {(void *) &intensity, (char *) "intensity", (char *) "Intensity",
      (char *) "2185", t_Int}
 };
 
@@ -97,7 +98,7 @@ ModeSpecOpt gasket_opts = {countof(opts), opts, countof(vars), vars, desc};
 ModStruct sierpinski3d_description =
 {"sierpinski3d", "init_gasket", "draw_gasket", "release_gasket",
  "draw_gasket", "init_gasket", (char *) NULL, &gasket_opts,
- 1000, 1, 2, 1, 64, 1.0, "",
+ 15000, 1, 2, 1, 64, 1.0, "",
  "Shows GL's Sierpinski gasket", 0, NULL};
 
 #endif
@@ -111,6 +112,12 @@ typedef struct{
 } GL_VECTOR;
 
 typedef struct {
+#ifdef WIN32
+    HGLRC glx_context;
+#else
+    GLXContext *glx_context;
+#endif
+  Window      window;
   GLfloat rotx, roty, rotz;	   /* current object rotation */
   GLfloat dx, dy, dz;		   /* current rotational velocity */
   GLfloat ddx, ddy, ddz;	   /* current rotational acceleration */
@@ -118,8 +125,6 @@ typedef struct {
 
   GLfloat     angle;
   GLuint      gasket1;
-  GLXContext *glx_context;
-  Window      window;
 
   int current_depth;
 
@@ -231,8 +236,8 @@ triangle (GLfloat x1, GLfloat y1, GLfloat z1,
 {
   if (wireframe_p)
     glBegin (GL_LINE_LOOP);
-  else 
-    { 
+  else
+    {
       do_normal (x1, y1, z1,  x2, y2, z2,  x3, y3, z3);
       glBegin (GL_TRIANGLES);
     }
@@ -337,26 +342,26 @@ compile_gasket(ModeInfo *mi)
   GL_VECTOR   vertex[5];
 
   /* define verticies */
-  vertex[0].x =  0.5; 
+  vertex[0].x =  0.5;
   vertex[0].y = -(1.0/3.0)*sqrt((2.0/3.0));
   vertex[0].z = -sqrt(3.0)/6.0;
 
-  vertex[1].x = -0.5; 
-  vertex[1].y = -(1.0/3.0)*sqrt((2.0/3.0)); 
-  vertex[1].z = -sqrt(3.0)/6.0; 
+  vertex[1].x = -0.5;
+  vertex[1].y = -(1.0/3.0)*sqrt((2.0/3.0));
+  vertex[1].z = -sqrt(3.0)/6.0;
 
-  vertex[2].x = 0.0; 
+  vertex[2].x = 0.0;
   vertex[2].y = (2.0/3.0)*sqrt((2.0/3.0));
-  vertex[2].z = -sqrt(3.0)/6.0; 
+  vertex[2].z = -sqrt(3.0)/6.0;
 
-  vertex[3].x = 0.0; 
-  vertex[3].y = 0.0; 
-  vertex[3].z = sqrt(3.0)/3.0; 
+  vertex[3].x = 0.0;
+  vertex[3].y = 0.0;
+  vertex[3].z = sqrt(3.0)/3.0;
 
   vertex[4].x = 0.0;
-  vertex[4].y = 0.0; 
+  vertex[4].y = 0.0;
   vertex[4].z = 0.0;
-  
+
   four_tetras (vertex, wireframe_p,
                (gp->current_depth < 0
                 ? -gp->current_depth : gp->current_depth));
@@ -368,22 +373,22 @@ draw(ModeInfo *mi)
   Bool wireframe_p = MI_IS_WIREFRAME(mi);
   gasketstruct *gp = &gasket[MI_SCREEN(mi)];
   static int tick = 0;
-  
+
   static GLfloat pos[4] = {1.0, 1.0, 1.0, 0.0};
   static float white[]  = {1.0, 1.0, 1.0, 1.0};
   static float color[]  = {0.0, 0.0, 0.0, 1.0};
 
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
-  if (!wireframe_p) 
+  if (!wireframe_p)
     {
       glColor4fv (white);
 
-      glLightfv(GL_LIGHT0, GL_POSITION,  pos); 
+      glLightfv(GL_LIGHT0, GL_POSITION,  pos);
 
-      color[0] = gp->colors[gp->ccolor].red  * intens_factor; 
+      color[0] = gp->colors[gp->ccolor].red  * intens_factor;
       color[1] = gp->colors[gp->ccolor].green * intens_factor;
-      color[2] = gp->colors[gp->ccolor].blue * intens_factor;  
+      color[2] = gp->colors[gp->ccolor].blue * intens_factor;
       gp->ccolor++;
       if (gp->ccolor >= gp->ncolors) gp->ccolor = 0;
 
@@ -392,7 +397,7 @@ draw(ModeInfo *mi)
       glShadeModel(GL_SMOOTH);
 
       glEnable(GL_LIGHTING);
-      glEnable(GL_LIGHT0); 
+      glEnable(GL_LIGHT0);
     }
 
   glEnable(GL_DEPTH_TEST);
@@ -464,7 +469,7 @@ reshape_gasket(ModeInfo *mi, int width, int height)
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();
   glTranslatef(0.0, 0.0, -15.0);
-  
+
   glClear(GL_COLOR_BUFFER_BIT);
 }
 
@@ -484,8 +489,8 @@ pinit(ModeInfo *mi)
 
 
 /* lifted from lament.c */
-#define RAND(n) ((long) ((random() & 0x7fffffff) % ((long) (n))))
-#define RANDSIGN() ((random() & 1) ? 1 : -1)
+#define RAND(n) ((long) ((LRAND() & 0x7fffffff) % ((long) (n))))
+#define RANDSIGN() ((LRAND() & 1) ? 1 : -1)
 
 static void
 rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
@@ -523,12 +528,12 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
   /* If it stops, start it going in the other direction. */
   else if (*v < 0)
     {
-      if (random() % 4)
+      if (NRAND(4) != 0)
 	{
 	  *v = 0;
 
 	  /* keep going in the same direction */
-	  if (random() % 2)
+	  if (LRAND() & 1)
 	    *dv = 0;
 	  else if (*dv < 0)
 	    *dv = -*dv;
@@ -543,15 +548,15 @@ rotate(GLfloat *pos, GLfloat *v, GLfloat *dv, GLfloat max_v, Bool verbose)
     }
 
   /* Alter direction of rotational acceleration randomly. */
-  if (! (random() % 120))
+  if (!(NRAND(120)))
     *dv = -*dv;
 
   /* Change acceleration very occasionally. */
-  if (! (random() % 200))
+  if (!(NRAND(200)))
     {
       if (*dv == 0)
 	*dv = 0.00001;
-      else if (random() & 1)
+      else if (LRAND() & 1)
 	*dv *= 1.2;
       else
 	*dv *= 0.8;
@@ -627,7 +632,12 @@ draw_gasket(ModeInfo * mi)
   if (max_depth > 10)
     max_depth = 10;
 
+  MI_IS_DRAWN(mi) = True;
+#ifdef WIN32
+  wglMakeCurrent(hdc, gp->glx_context);
+#else
   glXMakeCurrent(display, window, *(gp->glx_context));
+#endif
   draw(mi);
 
   /* rotate */
@@ -662,12 +672,16 @@ release_gasket(ModeInfo * mi)
       if (gp->glx_context)
       {
 	/* Display lists MUST be freed while their glXContext is current. */
+#ifdef WIN32
+	wglMakeCurrent(hdc, gp->glx_context);
+#else
         glXMakeCurrent(MI_DISPLAY(mi), gp->window, *(gp->glx_context));
+#endif
 
         if (glIsList(gp->gasket1)) glDeleteLists(gp->gasket1, 1);
       }
     }
-    (void) free((void *) gasket);
+    free(gasket);
     gasket = (gasketstruct *) NULL;
   }
   FreeAllGL(mi);
