@@ -40,6 +40,7 @@ static const char sccsid[] = "@(#)tik_tak.c	5.00 2000/11/01 xlockmore";
  */
 
 #ifdef STANDALONE
+#define MODE_tik_tak
 #define PROGCLASS "Tik_Tak"
 #define HACK_INIT init_tik_tak
 #define HACK_DRAW draw_tik_tak
@@ -63,8 +64,6 @@ static const char sccsid[] = "@(#)tik_tak.c	5.00 2000/11/01 xlockmore";
 
 #define DEF_CYCLE "True"
 
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-
 static Bool cycle_p;
 
 static XrmOptionDescRec opts[] =
@@ -75,7 +74,7 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
+	{(void *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -99,8 +98,8 @@ ModStruct   tik_tak_description =
 typedef struct {
 	unsigned long colour;
         Bool        inner;
-	float       angle, velocity_a , angle1 , velocity_a1;
-   float size_mult , size_mult1;
+	float       angle, velocity_a, angle1, velocity_a1;
+	float       size_mult, size_mult1;
 	int         num_point, size_ob;
 	int         num_point1, size_ob1;
 	XPoint      *xy , *xy1;
@@ -108,7 +107,7 @@ typedef struct {
 
 typedef struct {
 	Bool        painted;
-	int         win_width, win_height, num_object , x0 , y0;
+	int         win_width, win_height, num_object, x0, y0;
 	tik_takobject *object;
 	GC          gc;
 	Colormap    cmap;
@@ -126,7 +125,7 @@ static void
 tik_tak_setupobject( ModeInfo * mi , tik_takobject * object0)
 {
 	tik_takstruct *tiktak = &tik_taks[MI_SCREEN(mi)];
-	int         x0=tiktak->x0 , y0=tiktak->y0 , i;
+	int         x_0=tiktak->x0 , y_0=tiktak->y0 , i;
    float curangle;
 
    for (i = 0; i <= object0->num_point; i++)
@@ -140,10 +139,10 @@ tik_tak_setupobject( ModeInfo * mi , tik_takobject * object0)
 	object0->size_mult = 1.0 / object0->size_mult;
 	curangle = object0->angle + i * 360.0 * PI_RAD /
 	  (float) object0->num_point;
-	object0->xy[i+object0->num_point+1].x = x0 +
+	object0->xy[i+object0->num_point+1].x = x_0 +
 	  (int) (object0->size_ob * cos(curangle)) +
 	  (int) (object0->size_ob * sin(curangle));
-	object0->xy[i+object0->num_point+1].y = y0 +
+	object0->xy[i+object0->num_point+1].y = y_0 +
 	  (int) (object0->size_ob * cos(curangle)) -
 	  (int) (object0->size_ob * sin(curangle));
      }
@@ -164,10 +163,10 @@ tik_tak_setupobject( ModeInfo * mi , tik_takobject * object0)
 	     object0->size_mult1 = 1.0 / object0->size_mult1;
 	     curangle = object0->angle1 + i * 360.0 * PI_RAD /
 	       (float) object0->num_point1;
-	     object0->xy1[i+object0->num_point1+1].x = x0 +
+	     object0->xy1[i+object0->num_point1+1].x = x_0 +
 	       (int) (object0->size_ob1 * cos(curangle)) +
 	       (int) (object0->size_ob1 * sin(curangle));
-	     object0->xy1[i+object0->num_point1+1].y = y0 +
+	     object0->xy1[i+object0->num_point1+1].y = y_0 +
 	       (int) (object0->size_ob1 * cos(curangle)) -
 	       (int) (object0->size_ob1 * sin(curangle));
 	  }
@@ -228,7 +227,7 @@ free_tik_tak(Display *display, tik_takstruct *tiktak)
 		if (tiktak->colors != NULL) {
 			if (tiktak->ncolors && !tiktak->no_colors)
 				free_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors);
-			(void) free((void *) tiktak->colors);
+			free(tiktak->colors);
 			tiktak->colors = (XColor *) NULL;
 		}
 		if (tiktak->cmap != None) {
@@ -248,11 +247,11 @@ free_tik_tak(Display *display, tik_takstruct *tiktak)
 
 			object0 = &tiktak->object[i];
 		 	if (object0->xy1 != NULL)
-				(void) free((void *) object0->xy1);
+				free(object0->xy1);
 			if (object0->xy != NULL)
-				(void) free((void *) object0->xy);
+				free(object0->xy);
 		}
-		(void) free((void *) tiktak->object);
+		free(tiktak->object);
 		tiktak->object = (tik_takobject *) NULL;
 	 }
 }
@@ -345,23 +344,21 @@ init_tik_tak(ModeInfo * mi)
 			free_tik_tak(display, tiktak);
 			return;
 		}
-	size_object = min( tiktak->win_width , tiktak->win_height) / 3;
+	size_object = MIN( tiktak->win_width , tiktak->win_height) / 3;
 	if ( abs( MI_SIZE(mi) ) > size_object) {
 	   if ( MI_SIZE( mi ) < 0 )
 	     {
 		size_object = -size_object;
 	     }
+	} else {
+	  size_object = MI_SIZE(mi);
 	}
-   else
-     {
-	size_object = MI_SIZE(mi);
-     }
 	if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
 /* Set up colour map */
 		if (tiktak->colors != NULL) {
 			if (tiktak->ncolors && !tiktak->no_colors)
 				free_colors(display, tiktak->cmap, tiktak->colors, tiktak->ncolors);
-			(void) free((void *) tiktak->colors);
+			free(tiktak->colors);
 			tiktak->colors = (XColor *) NULL;
 		}
 		tiktak->ncolors = MI_NCOLORS(mi);
@@ -471,7 +468,7 @@ init_tik_tak(ModeInfo * mi)
 							    2 ) );
 	     }
 	   if (object0->xy != NULL)
-			(void) free((void *) object0->xy);
+			free(object0->xy);
 	   if ((object0->xy = (XPoint *) malloc(sizeof( XPoint ) *
 				(2 * object0->num_point + 2))) == NULL) {
 			free_tik_tak(display, tiktak);
@@ -498,7 +495,7 @@ init_tik_tak(ModeInfo * mi)
 		        ( 1.0 / (float) ((LRAND() & 1) + 2 ) );
 		  }
 		if (object0->xy1 != NULL)
-			(void) free((void *) object0->xy1);
+			free(object0->xy1);
 		if ((object0->xy1 = (XPoint *) malloc(sizeof( XPoint ) *
 				(2 * object0->num_point1 + 2))) == NULL) {
 			free_tik_tak(display, tiktak);
@@ -604,7 +601,7 @@ release_tik_tak(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_tik_tak(MI_DISPLAY(mi), &tik_taks[screen]);
-		(void) free((void *) tik_taks);
+		free(tik_taks);
 		tik_taks = (tik_takstruct *) NULL;
 	}
 }
