@@ -8,14 +8,17 @@ static const char sccsid[] = "@(#)sound.c	4.00 97/01/01 xlockmore";
  *
  * See xlock.c for copying information.
  *
+ * Revision History:
+ * 26-Oct-01: Allow wild cards on sound-files. (joukj@hrem.stm.tudelft.nl)
  */
 
 #include "xlock.h"
+#include "iostuff.h"
 
 #ifdef USE_RPLAY
 #include <rplay.h>
 
-void
+static void
 play_sound(char *filename, Bool verbose)
 {
 	int         rplay_fd = rplay_open_default();
@@ -37,10 +40,11 @@ play_sound(char *filename, Bool verbose)
 
 #include <audio/audio.h>
 #include <audio/audiolib.h>
+#include <audio/soundlib.h>
 
 extern Display *dsp;
 
-void
+static void
 play_sound(char *filename, Bool verbose)
 {
 	char       *auservername = DisplayString(dsp);
@@ -82,7 +86,7 @@ extern void PLAY_SOUND_MMOV(char* filename, Bool verbose);
 #include <iodef.h>
 #include "vms_amd.h"
 
-int
+static int
 play_sound_so(char *filename, Bool verbose)
 {
 	int         i, j, status;
@@ -95,7 +99,7 @@ play_sound_so(char *filename, Bool verbose)
 
 	status = AmdInitialize("SO:", volume);	/* Initialize access to AMD */
         if ( status !=0 ) return status;
-   
+
 	AmdSelect(speaker);	/* Select which speaker */
 	fp = open(filename, O_RDONLY, 0777);	/* Open the file */
 	if (!(fp == -1)) {
@@ -115,11 +119,11 @@ play_sound_so(char *filename, Bool verbose)
 #endif
 
 #if defined( HAS_MMOV ) || defined( USE_VMSPLAY )
-void
+static void
 play_sound(char* filename, Bool verbose)
 {
 #ifdef USE_VMSPLAY
-   if ( play_sound_so(filename, verbose) != 0 )
+   if (play_sound_so(filename, verbose) != 0 )
 #endif
      {
 #ifdef HAS_MMOV
@@ -128,7 +132,7 @@ play_sound(char* filename, Bool verbose)
 	privs[1] = 0;
 	privs[0] = PRV$M_SYSNAM;
 	pr_status = SYS$SETPRV ( 1, privs, 0, 0 );
-	
+
 	if ( pr_status == SS$_NORMAL ) PLAY_SOUND_MMOV(filename, verbose);
 #endif
      }
@@ -136,16 +140,16 @@ play_sound(char* filename, Bool verbose)
 #endif
 
 #ifdef DEF_PLAY
-void
+static void
 play_sound(char *filename, Bool verbose)
 {
 	char        *progrun = NULL;
 
-	if ((progrun = (char *) malloc(strlen(DEF_PLAY) + strlen(filename) + 10)) != NULL) {
-		(void) sprintf(progrun, "( %s%s ) 2>&1", DEF_PLAY, filename);
+	if ((progrun = (char *) malloc(strlen(DEF_PLAY) + strlen(filename) + 11)) != NULL) {
+		(void) sprintf(progrun, "( %s %s ) 2>&1", DEF_PLAY, filename);
 		/*(void) printf("%s\n", progrun); */
 		(void) system(progrun);
-		(void) free((void *) progrun);
+		free(progrun);
 	}
 }
 
@@ -200,7 +204,7 @@ static void	     	sound_esd_shutdown(void);
  * =============================
  */
 
-void
+static void
 play_sound(char *filename, Bool verbose)
 {
 #ifdef DEBUG
@@ -243,13 +247,13 @@ sound_esd_load_sample(char *file)
    struct stat	       stbuf;
    EsdSample_ptr       s;
    int                 in_format, in_width, in_channels, frame_count;
-   int                 bytes_per_frame, frames_read;
+   int                 bytes_per_frame;
    double              in_rate;
-   char 	      *origfile = strdup( file ? file : "" );
+   char 	      *origfile;
    char 	       fullfile[MAXPATHLEN];
 
 #ifdef DEBUG
-   (void) fprintf(stderr, "sound_esd_load_sample: %s\n", origfile);
+   (void) fprintf(stderr, "sound_esd_load_sample: %s\n", s->file);
 #endif
 
    s = EsdSamplesList;
@@ -258,6 +262,7 @@ sound_esd_load_sample(char *file)
    if ( s && !strcmp( file, s->file ) )
      return s;
 
+   origfile = strdup( file ? file : "" );
 #ifdef DEBUG
    (void) fprintf(stderr, "sound_esd_load_sample: sample not loaded: loading ...\n", origfile);
 #endif
@@ -270,23 +275,26 @@ sound_esd_load_sample(char *file)
    if (stat(file, &stbuf) < 0)
    {
        (void) fprintf( stderr, "Error ! Cannot find the sound file %s\n", file);
+       free(origfile); 
        return NULL;
    }
    if ( !( in_file = afOpenFile(file, "r", NULL) ) )
    {
        (void) fprintf( stderr, "Error ! Cannot open sound sample ! Bad format ?\n" );
-       return(NULL);
+       free(origfile); 
+       return NULL;
    }
    s = EsdSamplesList;
    if ( s )
    {
        while ( s && s->next )
          s = s->next;
-       s->next = malloc(sizeof(EsdSample_t));
+       s->next = (EsdSample_t *) malloc(sizeof(EsdSample_t));
        if ( !s->next )
        {
            (void) fprintf( stderr, "Error ! cannot allocate sample data !\n" );
-           afCloseFile(in_file);
+           (void) afCloseFile(in_file);
+       	   free(origfile); 
            return NULL;
        }
        s = s->next;
@@ -294,11 +302,12 @@ sound_esd_load_sample(char *file)
    }
    else
    {
-       s = malloc(sizeof(EsdSample_t));
+       s = (EsdSample_t *) malloc(sizeof(EsdSample_t));
        if ( !s )
        {
            (void) fprintf( stderr, "Error ! cannot allocate sample data !\n" );
-           afCloseFile(in_file);
+           (void) afCloseFile(in_file);
+       	   free(origfile); 
            return NULL;
        }
        EsdSamplesList = s;
@@ -311,7 +320,7 @@ sound_esd_load_sample(char *file)
    afGetSampleFormat(in_file, AF_DEFAULT_TRACK, &in_format, &in_width);
    afSetVirtualByteOrder(in_file, AF_DEFAULT_TRACK, (bigendian()) ?
 	AF_BYTEORDER_BIGENDIAN : AF_BYTEORDER_LITTLEENDIAN);
-   s->file = strdup(origfile);
+   s->file = origfile;
    s->rate = 44100;
    s->format = ESD_STREAM | ESD_PLAY;
    s->samples = 0;
@@ -330,15 +339,15 @@ sound_esd_load_sample(char *file)
    s->rate = (int)in_rate;
 
    s->samples = frame_count * bytes_per_frame;
-   s->data = malloc(frame_count * bytes_per_frame);
+   s->data = (unsigned char *) malloc(frame_count * bytes_per_frame);
    if ( !s->data )
    {
        (void) fprintf( stderr, "Error ! cannot allocate memory for sample !\n" );
-       afCloseFile(in_file);
+       (void) afCloseFile(in_file);
        return NULL;
    }
-   frames_read = afReadFrames(in_file, AF_DEFAULT_TRACK, s->data, frame_count);
-   afCloseFile(in_file);
+   (void) afReadFrames(in_file, AF_DEFAULT_TRACK, s->data, frame_count);
+   (void) afCloseFile(in_file);
    return s;
 }
 
@@ -426,7 +435,7 @@ sound_esd_shutdown(void)
     if (sound_fd >= 0)
     {
         EsdSample_ptr	s = EsdSamplesList;
- 
+
         while ( s )
         {
             EsdSamplesList = s->next;
@@ -440,3 +449,19 @@ sound_esd_shutdown(void)
 }
 
 #endif
+
+#ifdef USE_SOUND
+void
+playSound(char *filename, Bool verbose)
+{
+	char* actual_sound;
+
+	actual_sound = getSound(filename);
+	if (verbose && strcmp(actual_sound, filename) != 0) {
+		(void) printf("Requested sound file : %s\n", filename);
+		(void) printf("Selected sound file : %s\n" , actual_sound);
+	}
+	if (actual_sound)
+		play_sound(actual_sound, verbose);
+}
+#endif
